@@ -12,7 +12,7 @@ class TrunkPlanAdmin(admin.ModelAdmin):
 
 @admin.register(UCCluster)
 class UCClusterPlanAdmin(admin.ModelAdmin):
-    list_display = ("UCCluster", "tenant", "description", "publisher", "subscriber1", "subscriber2", "subscriber3", "subscriber4", "tftp1", "tftp2")
+    list_display = ("uccluster", "tenant", "description", "publisher", "subscriber1", "subscriber2", "subscriber3", "subscriber4", "tftp1", "tftp2")
 
 @admin.register(DevicePool)
 class DevicePoolPlanAdmin(admin.ModelAdmin):
